Learn R Programming

ssym (version 1.0)

ssym-package: Fitting Semiparametric Symmetric Regression Models

Description

This package allows to fit a semiparametric regression model suitable for data set analysis in which the conditional distribution of the response is symmetric and continuous.

Arguments

Details

ll{ Package: ssym Type: Package Version: 1.0 Date: 2014-03-30 License: GPL-2 | GPL-3 }

References

Vanegas, L.H. and Paula, G.A. (2014) A Semiparametric Approach for Joint Modeling of Median and Skewness. TEST (submitted) Vanegas, L.H. and Paula, G.A. (2014) Log-symmetric distributions: statistical properties and parameter estimation. Brazilian Journal of Probability and Statistics (submitted)

Examples

Run this code
library(NISTnls)
Chwirut <- Chwirut1[order(Chwirut1$x,Chwirut1$y),]
attach(Chwirut)

loc.f <- function(vP){
	          beta <- vP[1:3]
	         -beta[1]*x - log(beta[2] + beta[3]*x)	  
}
start <- c(b1=0.15, b2=0.005, b3=0.012)
fit <- ssym.nl(log(y),loc.f,start=start,ncs=x,family='Hyperbolic',xi=1,
               local.influence=TRUE)
summary(fit)

Run the code above in your browser using DataLab